@@ -32,7 +32,7 @@ def get_ASTROMER(num_layers=2,
                  maxlen=100,
                  batch_size=None,
                  pretrained_weights=False,
-                 overwrite=True):
+                 overwrite=False):
     if pretrained_weights:
         #model = load_weights(git_link="https://github.com/HarshVardhanGoyal/test_model.git", model_name="astromer_10022021")
         model_name="astromer_10022021"
@@ -43,26 +43,27 @@ def get_ASTROMER(num_layers=2,
             test_dir = tempfile.mkdtemp()
             git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
             time.sleep(2)
-            if os.path.isdir(model_path):
+            if os.path.path.exists(model_path):
                 if overwrite:
-                    shutil.rmtree(model_path)
+                    #shutil.rmtree(model_path)
+                    pass
                 else:
                     print("The saved weights already exists")
         except:
-            print("Couldn't load the model")
+            pass
         finally:
             sourcepath = os.path.join(test_dir, model_name)
             sourcefiles = os.listdir(sourcepath)
             destinationpath = os.path.join(model_path, model_name)
-            os.makedirs(destinationpath)
-            for file in sourcefiles:
-                if file.endswith('.index') or file.endswith('.data-00000-of-00001') or file.endswith('.json') or file.endswith("checkpoint"):
-                    print(sourcefiles)
-                    print(destinationpath)
-                    print(file)
-                    shutil.move(os.path.join(sourcepath,file), os.path.join(destinationpath,file))
+            os.makedirs(model_path)
+            # for file in sourcefiles:
+            #     if file.endswith('.index') or file.endswith('.data-00000-of-00001') or file.endswith('.json') or file.endswith("checkpoint"):
+            #         print(sourcefiles)
+            #         print(destinationpath)
+            #         print(file)
+            #         shutil.move(os.path.join(sourcepath,file), os.path.join(destinationpath,file))
 
-        #shutil.move(os.path.join(test_dir, model_name), model_path)
+        shutil.move(os.path.join(test_dir, model_name),model_path)
         # shutil.rmtree(test_dir)
 
         conf_file = os.path.join( model_path, model_name, 'conf.json')
@@ -80,7 +81,9 @@ def get_ASTROMER(num_layers=2,
 
         # Loading the model
         if os.path.isdir(model_path):
-            model = model.load_weights(os.path.join(destinationpath, "weights"))
+            model.load_weights(os.path.join(destinationpath, "weights"))
+            print("Weights loaded successfully!")
+
 
     else:
         serie  = Input(shape=(maxlen, 1),
